Sea ice is ice that floats on the surface of the ocean. It affects the transfer of heat, energy, momentum and gases between the atmosphere and ocean. Sea ice also plays an important role in many polar ecosystems. Sea-ice extent is a measure of the area of the ocean covered by sea ice.

Sea ice reflects sunlight and absorbs relatively little compared to dark ocean water. If sea ice cover is reduced, the surface absorbs far more sunlight and warms up. In turn the warming can reduce sea ice cover. This feedback is one reason that the Arctic has warmed faster than the global average.

The formation and persistence of sea ice is different in the northern and southern hemispheres. In the northern hemisphere, ice forms largely within the confines of the Arctic ocean, which is enclosed by the coasts of the northern land masses, and other partly enclosed seas. In the southern hemisphere, the ice forms around the edge of the Antarctic continent.

Because sea ice is floating ice, melting and growth of sea ice have little effect on sea level.

## What the IPCC says

A1.5 Human influence is very likely the main driver of the global retreat of glaciers since the 1990s and the decrease in Arctic sea ice area between 1979-1988 and 2010-2019 (decreases of about 40% in September and about 10% in March). There has been no significant trend in Antarctic sea ice area from 1979 to 2020 due to regionally opposing trends and large internal variability.

Chapter 2 Current Arctic sea ice coverage levels are the lowest since at least 1850 for both annual mean and late-summer values (high confidence) and for the past 1000 years for late-summer values (medium confidence). Between 1979 and 2019, Arctic sea ice area has decreased in both summer and winter, with sea ice becoming younger, thinner and more dynamic (very high confidence). Decadal means for Arctic sea ice area decreased from 6.23 million km2 in 1979-1988 to 3.76 million km2 in 2010-2019 for September and from 14.52 to 13.42 million km2 for March. Antarctic sea ice area has experienced little net change since 1979 (high confidence), with only minor differences between sea ice area decadal means for 1979-1988 (2.04 million km2 for February, 15.39 million km2 for September) and 2010-2019 (2.17 million km2 for February, 15.75 million km2 for September)